@@ -13,7 +13,7 @@ use File::Slurp ();
 use File::Spec ();
 use IO::File ();
 
-our $VERSION = '0.21_01';
+our $VERSION = '0.21_02';
 
 sub new {
     my ($self, %params) = (shift, @_);
@@ -165,7 +165,7 @@ sub _parse_data {
     }
     unless ($create_rc) {
         @data_parsed = do {               #  # description       
-	    split /#\s+.*\s+-\n/, $data; #  -     
+	    split /#\s+.*\s+?-\n/, $data; #  -     
         };
     }
     unless ($create_rc) {
@@ -176,10 +176,10 @@ sub _parse_data {
 	    next unless $line;
 	    if ($line =~ /^#/) {
 	        my ($arg) = split /\s+/, $line;
-	        $self->{disabled}{substr($arg,1)} = 1;
+	        $self->{disabled}{substr($arg, 1)} = 1;
 	    }
 	}
-        @data_parsed = map { s/^#.*?\n(.*)$/$1/gs; $_ } @data_parsed;
+        @data_parsed = map { 1 while s/^#.*?\n(.*)$/$1/gs; $_ } @data_parsed;
     }
     return $create_rc ? $data : @data_parsed;
 }
@@ -434,7 +434,7 @@ sub _write {
 sub _compose_header {
     my $self = shift;
     my ($insert_comments, $insert_statements);
-    my $note = '# Note: this file has been initially created by '.__PACKAGE__." $VERSION";
+    my $note = '# Note: this file has been initially generated by '.__PACKAGE__." $VERSION";
     if (defined($self->{make_code}{begin})) {
         $self->_do_verbose("Removing ExtUtils::MakeMaker as dependency\n");
         $self->{make_code}{begin} =~ s/[ ]*(?:require|use)\s+ExtUtils::MakeMaker\s*;//;
@@ -579,11 +579,11 @@ __DATA__
 # argument conversion 
 -
 NAME                  module_name
-DISTNAME              dist_name
-ABSTRACT              dist_abstract
-AUTHOR                dist_author
-VERSION               dist_version
-VERSION_FROM          dist_version_from
+#DISTNAME             dist_name
+#ABSTRACT             dist_abstract
+#AUTHOR               dist_author
+#VERSION              dist_version
+#VERSION_FROM         dist_version_from
 PREREQ_PM             requires
 PL_FILES              PL_files
 PM                    pm_files
@@ -600,9 +600,9 @@ clean.FILES           @add_to_cleanup
  
 # default arguments 
 -
-recommends	      HASH
-build_requires        HASH
-conflicts	      HASH
+#build_requires       HASH
+#recommends	      HASH
+#conflicts	      HASH
 license               unknown
 create_readme         1
 create_makefile_pl    passthrough
@@ -616,8 +616,8 @@ dist_author
 dist_version
 dist_version_from
 requires
-recommends
 build_requires
+recommends
 conflicts
 PL_files
 pm_files
@@ -791,8 +791,8 @@ that is, C<HASH> -> C<HASH>, etc.
 C<Module::Build> default arguments may be specified as key/value pairs. 
 Arguments attached to multidimensional structures are unsupported.
 
- recommends	       HASH
  build_requires        HASH
+ recommends	       HASH
  conflicts	       HASH
  license               unknown
  create_readme         1
@@ -813,8 +813,8 @@ unsorted order after preceedingly sorted arguments.
  dist_version
  dist_version_from
  requires
- recommends
  build_requires
+ recommends
  conflicts
  PL_files
  pm_files
